#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from pyramid.renderers import render
from zope.interface import Interface

from pyams_file.interfaces import IFile
from pyams_template.template import get_view_template
from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config
from pyams_utils.interfaces.tales import ITALESExtension


@adapter_config(name='video',
                context=(Interface, Interface, Interface),
                provides=ITALESExtension)
class VideoTALESExtension(ContextRequestViewAdapter):
    """Video TALES adapter

    This TALES adapter can be used to create a 'video' HTML tag
    embedding all video attributes.
    """

    _render = get_view_template()

    def render(self, context=None, controls=True, *args, **kwargs):
        """Video renderer

        Method signature accepts unused *args and **kwargs to match 'picture' TALES extension.
        """
        if context is None:
            context = self.context
        return render('templates/video.pt', {
            'video': context,
            'controls': controls
        }, request=self.request)


@adapter_config(name='media',
                context=(Interface, Interface, Interface),
                provides=ITALESExtension)
class MediaTALESExtension(ContextRequestViewAdapter):
    """Media TALES adapter

    This TALES adapter can be used to create any media HTML tag.
    Actually images and videos are supported, and the right renderer will be used according
    to context content type.
    """

    def render(self, context=None, lg_thumb='lg', lg_width=12, md_thumb='md', md_width=12,
               sm_thumb='sm', sm_width=12, xs_thumb='xs', xs_width=12, def_thumb=None, def_width=None,
               alt='', css_class=''):
        if context is None:
            context = self.context
        if not IFile.providedBy(context):
            return ''
        registry = self.request.registry
        if context.content_type.startswith('video/'):
            extension = registry.queryMultiAdapter((context, self.request, self.view), ITALESExtension, name='video')
        elif context.content_type.startswith('image/'):
            extension = registry.queryMultiAdapter((context, self.request, self.view), ITALESExtension, name='picture')
        else:
            extension = None
        if extension is not None:
            return extension.render(context, lg_thumb=lg_thumb, lg_width=lg_width,
                                    md_thumb=md_thumb, md_width=md_width, sm_thumb=sm_thumb, sm_width=sm_width,
                                    xs_thumb=xs_thumb, xs_width=xs_width, def_thumb=def_thumb, def_width=def_width,
                                    alt=alt, css_class=css_class)
        else:
            return ''
